@@ -1,4 +1,4 @@
-//  Gant -- A Groovy build framework based on scripting Ant tasks.
+//  Gant -- A Groovy way of scripting Ant tasks.
 //
 //  Copyright © 2006-8 Russel Winder
 //
@@ -43,20 +43,37 @@ import org.apache.tools.ant.Project ;
  *  @author Russel Winder <russel.winder@concertant.com>
  */
 public class GantBuilder extends AntBuilder {
+  /**
+   *  Constructor that uses the default project.
+   */
   public GantBuilder ( ) { }
+  /**
+   *  Constructor that specifies which <code>Project</code> to be associated with.
+   *
+   *  @param project The <code>Project</code> to be associated with.
+   */
   public GantBuilder ( final Project project ) { super ( project ) ; }
-  public Object invokeMethod ( final String name , final Object arguments ) {
+  /**
+   *  Invoke a method.
+   *
+   *  @param name The name of the method to invoke.
+   *  @param arguments The parameters to the method call.
+   *  @return The value returned by the method call or null if no value is returned.
+   */
+  @Override @SuppressWarnings ( "unchecked" ) public Object invokeMethod ( final String name , final Object arguments ) {
     if ( GantState.dryRun ) {
       if ( GantState.verbosity > GantState.SILENT ) {
         int padding = 9 - name.length ( ) ;
         if ( padding < 0 ) { padding = 0 ; }
-        System.out.print ( "         ".substring ( 0 , padding ) + "[" + name + "] ") ;
+        System.out.print ( "         ".substring ( 0 , padding ) + '[' + name + "] ") ;
         final Object[] args = (Object[]) arguments ;
         if ( args[0] instanceof Map ) {
-          final Iterator<Map.Entry> i = ( (Map) args[0] ).entrySet ( ).iterator ( ) ;
+          // NB IntelliJ IDEA complains that (Map) is not a proper cast but using the cast (Map<?,?>) here
+          // causes a type check error.
+          final Iterator<Map.Entry<?,?>> i = ( (Map) args[0] ).entrySet ( ).iterator ( ) ;
           while ( i.hasNext ( ) ) {
-            final Map.Entry e = i.next ( ) ;
-            System.out.print ( e.getKey ( ) + " : '" + e.getValue ( ) + "'" ) ;
+            final Map.Entry<?,?> e = i.next ( ) ;
+            System.out.print ( e.getKey ( ) + " : '" + e.getValue ( ) + '\'' ) ;
             if ( i.hasNext ( ) ) { System.out.print ( " , " ) ; }
           }
           System.out.println ( ) ;
@@ -80,7 +97,7 @@ public class GantBuilder extends AntBuilder {
       final Field field = getClass ( ).getSuperclass ( ).getDeclaredField ( "project" ) ;
       field.setAccessible ( true ) ;
       final Project project = (Project) field.get ( this ) ;
-      final List listeners = project.getBuildListeners ( ) ;
+      final List<?> listeners = project.getBuildListeners ( ) ;
       assert listeners.size ( ) == 1 ;
       final BuildLogger logger = (BuildLogger) listeners.get ( 0 ) ;
       logger.setMessageOutputLevel ( GantState.verbosity ) ;
